@@ -92,7 +92,7 @@ void callforwardingdialog_show (GtkWindow *parent,
   g_signal_connect(GTK_OBJECT(select_contact), "clicked",
                    G_CALLBACK(select_contact_clicked), NULL);
 
-  if (type == SS_DIVERT_NO_REPLY)
+  if (type == CALLFORWARDING_NO_ANSWER)
   {
     GtkWidget *selector = hildon_touch_selector_new_text ();
     hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR(selector), "5");
@@ -108,12 +108,14 @@ void callforwardingdialog_show (GtkWindow *parent,
     hildon_button_set_title (HILDON_BUTTON (picker), _("Seconds before fowarding"));
     hildon_button_set_alignment (HILDON_BUTTON (picker), 0, 0, 0, 0);
     gtk_box_pack_start (GTK_BOX(vbox), picker, FALSE, FALSE, 0);
+  } else {
+    picker = NULL;
   }
 
   gtk_container_add (GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), vbox);
 
   // NO_AVAIL is only for set, status can't queried
-  if (type == SS_DIVERT_NO_AVAIL)
+  if (type == CALLFORWARDING_NO_AVAIL)
   {
     set_dialog_sensitivity ();
     gtk_widget_show_all (dialog);
@@ -178,7 +180,7 @@ static void dialog_response (GtkDialog *dialog,
         }
         gtk_dialog_set_response_sensitive (GTK_DIALOG(dialog), GTK_RESPONSE_OK, FALSE);
         hildon_gtk_window_set_progress_indicator (GTK_WINDOW(dialog), TRUE);
-        gint time = 20;
+        gint time = 0;
         if (picker != NULL)
         {
           gint index = hildon_picker_button_get_active (HILDON_PICKER_BUTTON(picker));
@@ -186,6 +188,8 @@ static void dialog_response (GtkDialog *dialog,
           {
             int times[] = {5, 10, 15, 20, 25, 30};
             time = times[index];
+          } else {
+            time = 20;
           }
         }
         callforwarding_activate (call_forwarding_type, number, time, callforwarding_activate_reply);
