@@ -61,27 +61,27 @@ void maindialog_show (GtkWindow *parent)
   gtk_box_pack_start (GTK_BOX(vbox), label, FALSE, FALSE, 0);
 
   /* Busy */
-  static gint busy = SS_DIVERT_BUSY;
+  static gint busy = CALLFORWARDING_BUSY;
   button = create_button (_("Busy"), G_CALLBACK(button_clicked), &busy);
   gtk_box_pack_start (GTK_BOX(vbox), button, FALSE, FALSE, 0);
 
   /* No answer */
-  static gint no_answer = SS_DIVERT_NO_REPLY;
+  static gint no_answer = CALLFORWARDING_NO_ANSWER;
   button = create_button (_("No answer"), G_CALLBACK(button_clicked), &no_answer);
   gtk_box_pack_start (GTK_BOX(vbox), button, FALSE, FALSE, 0);
 
   /* Out of reach */
-  static gint no_reach = SS_DIVERT_NO_REACH;
+  static gint no_reach = CALLFORWARDING_NO_REACH;
   button = create_button (_("Out of reach"), G_CALLBACK(button_clicked), &no_reach);
   gtk_box_pack_start (GTK_BOX(vbox), button, FALSE, FALSE, 0);
 
   /* Not available */
-  static gint not_available = SS_DIVERT_NO_AVAIL;
+  static gint not_available = CALLFORWARDING_NO_AVAIL;
   button = create_button (_("Not available"), G_CALLBACK(button_clicked), &not_available);
   gtk_box_pack_start (GTK_BOX(vbox), button, FALSE, FALSE, 0);
 
   /* Unconditional */
-  static gint unconditional = SS_DIVERT_ALL;
+  static gint unconditional = CALLFORWARDING_UNCONDITIONAL;
   button = create_button (_("Unconditional"), G_CALLBACK(button_clicked), &unconditional);
   gtk_box_pack_start (GTK_BOX(vbox), button, FALSE, FALSE, 0);
 
